Index: sdk/lib/io/http.dart |
diff --git a/sdk/lib/io/http.dart b/sdk/lib/io/http.dart |
index 452dbe7cc4cfa1cc44e50af59b61776d390b4c58..5d316eb7890c5356330b7c30a41fb894f6e9cf5e 100644 |
--- a/sdk/lib/io/http.dart |
+++ b/sdk/lib/io/http.dart |
@@ -168,10 +168,13 @@ abstract class HttpServer implements Stream<HttpRequest> { |
=> new _HttpServer.listenOn(serverSocket); |
/** |
* Permanently stops this [HttpServer] from listening for new connections. |
* This closes this [Stream] of [HttpRequest]s with a done event. |
*/ |
- void close(); |
+ Future close(); |
/** |
* Returns the port that the server is listening on. This can be |
@@ -168,10 +168,13 @@ abstract class HttpServer implements Stream<HttpRequest> { |
=> new _HttpServer.listenOn(serverSocket); |
/** |
- * Permanently stops this [HttpServer] from listening for new connections. |
- * This closes this [Stream] of [HttpRequest]s with a done event. |
+ * Permanently stops this [HttpServer] from listening for new |
+ * connections. This closes this [Stream] of [HttpRequest]s with a |
+ * done event. The returned future completes when the server is |
+ * stopped. For a server started using [bind] or [bindSecure] this |
+ * means that the port listened on no longer in use. |
*/ |